function result=ProDiGe4(featureFile,posSet, varargin)

% Runs ProDiGe4. The function takes as input a file containing features for
% a set of positive and unlabeled pairs disease/genes and predicts scores 
% for the unlabeled pairs.
% INPUT
% - featureFile : a mat-file name containing a Gram matrix named 'Kernel'
% - posSet : The indices of the positive examples
%
% OPTIONAL ARGUMENTS
% - testSet: indexes of pairs (disease, gene) to predict. If not precised,
% ProDiGe4 will score all unlabeled pairs. If there are many diseases and
% genes, this can take a lot of time and even cause memory issues.
% Therefore, it is recommended to use it to predict associations for a few
% diseases at a time.
% - C
% - NbScore
% - fileType
% - kernelType
%
% SEE ALSO help of functions fmethod and initializeMulti for more details
%
% OUTPUT:
%  a vector of predicted scores for the unlabeled examples from the testSet
%  field of the input Data object, mean score and bootstrap subsamples.
%
% USAGE
% example: make predictions for the first disease
% posSet=dlmread('../data/newHprd/associationsPairs.txt')
% testSet=1:9670;
% result=ProDiGe4(struct('data1','../data/newHprd/PhenoSimDirac.mat','data2', '../data/newHprd/PPIdiffusion.mat'),posSet, 'testSet', testSet)

C=1;
NbScore=30;
kernelType1= 'precomputed';
kernelType2= 'precomputed';
testSet='';

if ~isdeployed()
    addpath(genpath('../src/'))
end

% Parse optional arguments
l=1;
while (l<length(varargin))
    varargin{l} = varargin{l+1};
    l = l+2;
end

method=fmethod('MultiSVM','kernelType1', kernelType1, 'kernelType2', kernelType2, 'NbScore', NbScore,'C',C);
Data=initializeMulti(featureFile, posSet, method, 'testSet', testSet);
clear method

result=predict_multisvm(Data);