function runProDiGe4LOO(varargin)

% Runs a leave-one-out cross validation to assess the performance of
% ProDiGe4 for every disease with an entry in the phenotypic similarity 
% matrix. Each association (D,G) is removed in turn from the training set.
% ProDiGe4 is run and all unlabeled genes are prioritized for disease D.
% The performance is measured by the rank of gene G among the unlabeled
% set. The prioritization results for each fold are saved in separate files.
%
% ADDITIONAL ARGUMENTS
% - resultpathInit : the name of the path in which the results should be
%                    saved
% - C : the value of the regularization parameter of the SVM
%       (default : 1)
%
% EXAMPLE:
% runProDiGe4LOO
% runProDiGe4LOO('resultPathInit','./res/', 'C',10)

resultpathInit='./';
C=1;

if ~isdeployed()
    addpath(genpath('../src'))
end

% Parse optional arguments
l=1;
while (l<length(varargin))
    varargin{l} = varargin{l+1};
    l = l+2;
end

% Pheno+Dirac kernel on disorders + sum of 9 kernels for genes
kernels.data1 = '../data/newHprd/PhenoSimDirac.mat';
kernels.data2 = '../data/newHprd/PPIdiffusion.mat';

% index of positive pairs
posSet=dlmread('../data/newHprd/associationsPairs.txt');

method=fmethod('MultiSVM','kernelType1','precomputed', 'kernelType2', 'precomputed', 'NbScore', 30,'C',C);
Data=initializeMulti(kernels, posSet, method, 'testSet',1);
% bogus testSet to avoid the 'diffset' in initializeMulti, which is time-consuming
clear method

labelTrue=-ones(Data.nexample1*Data.nexample2,1);
labelTrue(Data.posSet)=0;

sData=Data;
for k=1:length(Data.posSet)
    if ~exist([resultpathInit,'fold',num2str(k),'.mat'], 'file')
        save([resultpathInit,'fold',num2str(k),'.mat'],'k')
        disp(['######## fold ',num2str(k), ' ########'])
        
        % set the positive training set leaving out the k-th association
        fold=ones(1,length(Data.posSet));
        fold(k)=0;
        sData.posSet=Data.posSet(fold==1);
        
        % find indexes of the disease and gene within the left-out pair
        [ind2 ind1]=ind2sub([Data.nexample2 Data.nexample1],Data.posSet(k));
        % true labels : 0=training positive, 1=unlabeled positive, -1=unlabeled
        label=labelTrue;
        label(Data.posSet(k))=1;
        % restrict to pairs with the same disorder as the left out pair and
        % set the test set to those pairs in sData
        label=label(Data.nexample2*(ind1-1)+(1:Data.nexample2));
        sData.testSet=Data.nexample2*(ind1-1)+(1:Data.nexample2);
        
        score = predict(sData);
        score=score.score;

        % save results
        save([resultpathInit,'fold',num2str(k),'.mat'], 'label', 'score')
        clear score label
    end
end
