function posSplit = split(Data, varargin)

% Aims at building folds of positive examples for validation. 
% Moreover the splits are designed in such a way that two positive examples
% in the same group are always in the same split.
%
% INPUT :
%  - Data : a structure containing the features, the positive and unlabeled
%  examples various parameters, as initialized by initialize()
%
% OPTIONAL ARGUMENTS :
%  - NbPos : an integer indicating how many positive examples should be
%  used for learning. The set of positive examples is then split into
%  subsets of roughly NbPos elements and these sets will be used
%  successively as positive training sets.
%  - Nrepeats : the number of bootstrap samples to be drawn. This additional
%  argument causes the positive set to be sampled from Nrepeats subsamples of
%  size NbPos.

NbPos=NaN;
Nrepeats=NaN;

% Parse optional arguments
l=1;
while (l<length(varargin))
    eval(strcat(varargin{l},' = ', num2str(varargin{l+1}), ';'));
    l = l+2;
end

labels = zeros(Data.nexample,1);
labels(Data.posSet)=1;

if ~isnan(NbPos)
    if NbPos > sum(labels)
        error('Argument NbPos is too big')
    end
    if ~isnan(Nrepeats)
        posSplit = cell(Nrepeats,1);
        for k=1:Nrepeats
            posSplit{k} = struct('train', [], 'test', []);
            randPos = randperm(length(Data.posSet));
            posSplit{k}.train = Data.posSet(randPos(1:NbPos));
            posSplit{k}.test = Data.posSet(randPos((1+NbPos):end));
        end
        return;
    else
        nsplit = ceil(sum(labels)/NbPos);
    end   
else
    nsplit = Data.nsplitCvOut;
end

posSplit = cell(1,nsplit);
% initialization
for k=1:nsplit
    posSplit{k} = struct('train', [], 'test', []);
end

posSplit = groupsplit(Data.posSet,1:length(Data.posSet),nsplit);


